@@ -480,6 +480,14 @@ def member_position(member_id):
     exporter.member_position(member_id=member_id)
 
 
+@click.command()
+def rename():
+    """Rename keys to kebab case"""
+    import exporter
+
+    exporter.rename_keys()
+
+
 @click.command()
 @click.argument("doi")
 @click.option(
@@ -539,6 +547,7 @@ if __name__ == "__main__":
     cli.add_command(process_member)
     cli.add_command(process_members)
     cli.add_command(random_samples)
+    cli.add_command(rename)
     cli.add_command(rescore)
     cli.add_command(score_member)
     cli.add_command(show_archives)
