@@ -898,6 +898,49 @@ def member_position(members=None, limit=0, member_id=None):
     )
 
 
+def rename_keys(members=None, limit=0, member_id=None):
+    import boto3
+    import logging
+
+    s3client = boto3.client("s3")
+    session = boto3.Session()
+    s3 = session.resource("s3")
+
+    if not members:
+        # get member list from S3
+        members = get_members(
+            s3client=s3client,
+            samples_bucket=SAMPLES_BUCKET,
+            samples_path=SAMPLES_PATH,
+        )
+
+    for member in members:
+        member_annotation = get_annotation(
+            s3client,
+            member,
+            ANNOTATION_BUCKET,
+            ANNOTATION_PATH,
+            "preservation.json",
+        )
+
+        new_annotation = {}
+
+        for key, value in member_annotation.items():
+            new_key = normalize_json_key(key)
+            new_annotation[new_key] = value
+
+        key = f"{ANNOTATION_PATH}/members/{member}/preservation.json"
+
+        push_json_to_s3(
+            s3=s3,
+            json_obj=new_annotation,
+            bucket=ANNOTATION_BUCKET,
+            path=key,
+        )
+
+        logging.info(f"Renamed keys for {member} in {key}")
+
+
 def rescore_all(members=None, limit=0):
     import boto3
     from rich.progress import track
