@@ -922,11 +922,11 @@ class OculScholarsPortalPreservation(models.Model):
                         unpack_volume_regex, pi.preserved_volumes
                     )
 
-                    unpacked_range = utils.unpack_range(matches)
-                    print(f"Range unpacked to: {unpacked_range}")
+                    for match in matches:
+                        unpacked_range = utils.unpack_range(match)
 
-                    if volume in unpacked_range:
-                        return pi, pi.preserved
+                        if volume in unpacked_range:
+                            return pi, pi.preserved
 
             pis = preserved_item.filter(preserved_volumes=volume)
             return None, False
